@@ -270,6 +270,8 @@ my %files_by_type = (
     'author.t/perltidyrc'               => \&trivial,
     'author.t/spelling_exceptions.list' => \&trivial,
     'author.t/tidy1'                    => \&trivial,
+    'etc/pod_errors.pl' => \&trivial,
+    'etc/pod_dump.pl' => \&trivial,
     'etc/dovg.sh'                       => \&trivial,
     'etc/compile_for_debug.sh'          => \&trivial,
     'etc/libmarpa_test.sh'              => \&trivial,
